@@ -109,7 +109,15 @@ kernel_sendmsg(atmlec_msg_type type, unsigned char *mac_addr,
 
   memset(mesg, 0, sizeof(struct atmlec_msg) + datalen);
   mesg->type = type;
-  if (type != l_config) {
+
+  if (type == l_config)
+    memcpy(&mesg->content.config, config, sizeof(struct atmlec_config_msg));
+  else if (type == l_should_bridge) {
+      memcpy(mesg->content.proxy.mac_addr, mac_addr, ETH_ALEN);
+      mesg->content.proxy.tran_id = flag;
+      mesg->content.proxy.lec_id = no_source_le_narp; /* cheat with arguments */
+  }
+  else {
     if (mac_addr)
       memcpy(&mesg->content.normal.mac_addr, mac_addr, ETH_ALEN);
     if (atm_addr)
@@ -117,8 +125,7 @@ kernel_sendmsg(atmlec_msg_type type, unsigned char *mac_addr,
     mesg->content.normal.flag = flag;
     mesg->content.normal.targetless_le_arp = targetless_le_arp; /* LANE2 */
     mesg->content.normal.no_source_le_narp = no_source_le_narp;
-  } else
-    memcpy(&mesg->content.config, config, sizeof(struct atmlec_config_msg));
+  }
 
   mesg->sizeoftlvs = datalen;
   if (datalen > 0)
@@ -167,6 +174,8 @@ get_mesg_type_str(atmlec_msg_type type)
     return "CONFIG";
   case l_associate_req:
     return "LANE2_ASSOCIATE_REQ";
+  case l_should_bridge:
+    return "SHOULD_BRIDGE";
   default:
     return "UNKNOWN MSG TYPE";
   }
