@@ -1,6 +1,6 @@
 /* diag.c - Diagnostic messages */
 
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -31,7 +31,8 @@ static int sev2prio[] = { DIAG_DEBUG,LOG_DEBUG, DIAG_INFO,LOG_INFO,
 static const char *app_name = NULL;
 static COMPONENT *components = NULL;
 static int default_verbosity = DIAG_INFO;
-static FILE *log_to = stderr;
+static FILE *log_to = NULL;
+static int log_to_initialized = 0;
 
 
 void set_application(const char *name)
@@ -96,6 +97,10 @@ void set_logfile(const char *name)
 
 FILE *get_logfile(void)
 {
+    if (!log_to_initialized) {
+	log_to = stderr;
+	log_to_initialized = 1;
+    }
     return log_to;
 }
 
@@ -115,6 +120,7 @@ void diag_fatal_debug_hook(void)
 void vdiag(const char *component,int severity,const char *fmt,va_list ap)
 {
     COMPONENT *walk;
+    FILE *to;
     char buffer[MAX_DIAG_MSG+1];
     int i;
 
@@ -122,17 +128,18 @@ void vdiag(const char *component,int severity,const char *fmt,va_list ap)
 	if (!strcmp(walk->name,component)) break;
     if (severity > (walk ? walk->verbosity : default_verbosity)) return;
     fflush(stdout);
-    if (!log_to) {
+    to = get_logfile();
+    if (!to) {
 	for (i = 0; sev2prio[i] == severity || sev2prio[i] == -1; i += 2);
 	vsprintf(buffer,fmt,ap);
 	syslog(sev2prio[i+1],"%s: %s",component,buffer);
     }
     else {
-	if (app_name) fprintf(log_to,"%s:%s: ",app_name,component);
-	else fprintf(log_to,"%s: ",component);
-	vfprintf(log_to,fmt,ap);
-	fputc('\n',log_to);
-	fflush(log_to);
+	if (app_name) fprintf(to,"%s:%s: ",app_name,component);
+	else fprintf(to,"%s: ",component);
+	vfprintf(to,fmt,ap);
+	fputc('\n',to);
+	fflush(to);
     }
     if (severity == DIAG_FATAL) {
 	diag_fatal_debug_hook();
