@@ -11,6 +11,7 @@
 #include <signal.h>
 #include <limits.h>
 #include <sys/types.h>
+#include <linux/atmdev.h>
 
 #include "atm.h"
 #include "atmd.h"
@@ -41,7 +42,8 @@ SIG_ENTITY _entity = {
 	0,		/* unspecified UNI version */
 	sm_user,	/* mode */
 	-1,		/* sig_pcr; obsolete @@@ */
-	NULL		/* sig_qos */
+	NULL,		/* sig_qos */
+	-1		/* max_rate */
 };
 
 
@@ -466,6 +468,8 @@ int main(int argc,char **argv)
     init_current_time();
     q_start();
     for (sig = entities; sig; sig = sig->next) {
+	set_vpi_0(sig);
+	if (sig->max_rate < 0) sig->max_rate = get_max_rate(sig);
 	if (sig->mode != sm_switch) init_addr(sig);
 	start_saal(&sig->saal,&ops,sig,
 	  sig->uni == S_UNI30 ? sscop_qsaal1 : sscop_q2110);
