@@ -188,7 +188,7 @@ char **argv;
 {
     struct timeval td;
     unsigned long addr_tmp;
-    const char *port_name;
+    const char *port_name = NULL;
     int c;
     double mbps;
 int no_check = 0;
